@@ -42,7 +42,7 @@ examples/remote.py for more information.)
 
 import xml.dom
 
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 
 class RemoteNode(object):
 
@@ -160,7 +160,28 @@ class khtmlImplementation(Implementation):
 
     def convert(self, _node):
         if _node.nodeType() == xml.dom.Node.ELEMENT_NODE:
-            return self.khtml.DOM.Element(_node)
+
+            # Promote underlying nodes to more capable HTML element objects.
+
+            if self.get_string(_node.namespaceURI()) == xml.dom.XHTML_NAMESPACE:
+                localName = self.get_string(_node.localName()).lower()
+                if localName == "select":
+                    return self.khtml.DOM.HTMLSelectElement(_node)
+                elif localName == "option":
+                    return self.khtml.DOM.HTMLOptionElement(_node)
+                elif localName == "input":
+                    return self.khtml.DOM.HTMLInputElement(_node)
+                elif localName == "button":
+                    return self.khtml.DOM.HTMLButtonElement(_node)
+                elif localName == "form":
+                    return self.khtml.DOM.HTMLFormElement(_node)
+                elif localName == "textarea":
+                    return self.khtml.DOM.HTMLTextAreaElement(_node)
+                else:
+                    return self.khtml.DOM.Element(_node)
+            else:
+                return self.khtml.DOM.Element(_node)
+
         elif _node.nodeType() == xml.dom.Node.ATTRIBUTE_NODE:
             return self.khtml.DOM.Attr(_node)
         elif _node.nodeType() == xml.dom.Node.DOCUMENT_NODE:
@@ -624,6 +645,198 @@ class Node(object):
     def toString(self, encoding="utf-8"):
         return self.toUnicode().encode(encoding)
 
+    # Extended methods for HTML DOMs.
+
+    def _getAccessKey(self):
+        return self.impl.get_string(self._node.accessKey())
+
+    def _setAccessKey(self, accessKey):
+        self._node.setAccessKey(self.impl.make_string(accessKey))
+
+    def _getForm(self):
+        return Node(self._node.form(), self.impl)
+
+    def _getName(self):
+        return self.impl.get_string(self._node.name())
+
+    def _setName(self, name):
+        self._node.setName(self.impl.make_string(name))
+
+    accessKey = property(_getAccessKey, _setAccessKey)
+    form = property(_getForm)
+    name = property(_getName, _setName)
+
+    # HTML input and button methods.
+
+    def _getType(self):
+        return self.impl.get_string(self._node.type())
+
+    def _setType(self, type):
+        self._node.setType(self.impl.make_string(type))
+
+    def _getValue(self):
+        return self.impl.get_string(self._node.value())
+
+    def _setValue(self, value):
+        self._node.setValue(self.impl.make_string(value))
+
+    def _getDisabled(self):
+        return self._node.disabled()
+
+    def _setDisabled(self, disabled):
+        self._node.setDisabled(disabled)
+
+    type = property(_getType, _setType)
+    value = property(_getValue, _setValue)
+    disabled = property(_getDisabled, _setDisabled)
+
+    # HTML input methods.
+
+    def _getChecked(self):
+        return self._node.checked()
+
+    def _setChecked(self, checked):
+        self._node.setChecked(checked)
+
+    def _getMaxLength(self):
+        return self._node.maxLength()
+
+    def _setMaxLength(self, maxLength):
+        self._node.setMaxLength(maxLength)
+
+    def _getSize(self):
+        return self._node.getSize()
+
+    def _setSize(self, size):
+        self._node.setSize(size)
+
+    def _getAccept(self):
+        return self.impl.get_string(self._node.accept())
+
+    def _setAccept(self, accept):
+        self._node.setAccept(self.impl.make_string(accept))
+
+    checked = property(_getChecked, _setChecked)
+    maxLength = property(_getMaxLength, _setMaxLength)
+    size = property(_getSize, _setSize)
+    accept = property(_getAccept, _setAccept)
+
+    def select(self):
+        self._node.select()
+
+    def click(self):
+        self._node.click()
+
+    # HTML option methods.
+
+    def _getSelected(self):
+        return self._node.selected()
+
+    def _setSelected(self, selected):
+        self._node.setSelected(selected)
+
+    def _getDefaultSelected(self):
+        return self._node.defaultSelected()
+
+    def _setDefaultSelected(self, selected):
+        self._node.setDefaultSelected(selected)
+
+    selected = property(_getSelected, _setSelected)
+    defaultSelected = property(_getDefaultSelected, _setDefaultSelected)
+
+    # HTML select methods.
+
+    def _getSelectedIndex(self):
+        return self._node.selectedIndex()
+
+    def _setSelectedIndex(self, selectedIndex):
+        self._node.setSelectedIndex(selectedIndex)
+
+    def _getMultiple(self):
+        return self._node.multiple()
+
+    def _setMultiple(self, multiple):
+        self._node.setMultiple(multiple)
+
+    def _getLength(self):
+        return self._node.length()
+
+    def _getOptions(self):
+        return NamedNodeMap(self._node.options(), self.impl)
+
+    selectedIndex = property(_getSelectedIndex, _setSelectedIndex)
+    multiple = property(_getMultiple, _setMultiple)
+    length = property(_getLength)
+    options = property(_getOptions)
+
+    # HTML textarea methods.
+
+    def _getCols(self):
+        return self._node.cols()
+
+    def _setCols(self, cols):
+        self._node.setCols(cols)
+
+    def _getRows(self):
+        return self._node.rows()
+
+    def _setRows(self, rows):
+        self._node.setRows(rows)
+
+    def _getDefaultValue(self):
+        return self.impl.get_string(self._node.defaultValue())
+
+    def _setDefaultValue(self, defaultValue):
+        self._node.setDefaultValue(self.impl.make_string(defaultValue))
+
+    cols = property(_getCols, _setCols)
+    rows = property(_getRows, _setRows)
+    defaultValue = property(_getDefaultValue, _setDefaultValue)
+
+    # HTML form methods.
+
+    def _getAcceptCharset(self):
+        return self.impl.get_string(self._node.acceptCharset())
+
+    def _setAcceptCharset(self, charset):
+        self._node.setAcceptCharset(self.impl.make_string(charset))
+
+    def _getAction(self):
+        return self.impl.get_string(self._node.action())
+
+    def _setAction(self, action):
+        self._node.setAction(self.impl.make_string(action))
+
+    def _getEnctype(self):
+        return self.impl.get_string(self._node.enctype())
+
+    def _setEnctype(self, enctype):
+        self._node.setEnctype(self.impl.make_string(enctype))
+
+    def _getMethod(self):
+        return self.impl.get_string(self._node.method())
+
+    def _setMethod(self, method):
+        self._node.setMethod(self.impl.make_string(method))
+
+    def _getTarget(self):
+        return self.impl.get_string(self._node.target())
+
+    def _setTarget(self, target):
+        self._node.setTarget(self.impl.make_string(target))
+
+    acceptCharset = property(_getAcceptCharset, _setAcceptCharset)
+    action = property(_getAction, _setAction)
+    enctype = property(_getEnctype, _setEnctype)
+    method = property(_getMethod, _setMethod)
+    target = property(_getTarget, _setTarget)
+
+    def submit(self):
+        self._node.submit()
+
+    def reset(self):
+        self._node.reset()
+
 # Convenience functions.
 
 def getRemoteDocument(remote_object):
